==> mmdx-tags_v1.41a-r928.tar.gz: mmdx-tags_v1.41a-r928/v1.41a/MikuMikuDanceXNADemo/Game1.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using MikuMikuDance.XNA.Model;
using MikuMikuDance.XNA;
using MikuMikuDance.XNA.Motion;

namespace MikuMikuDanceXNADemo
{
    /// <summary>
    /// MikuMikuDance for XNÃf
    /// ̃fłMMDX̊{ł
    /// -MikuMikuDanceXNAIuWFNg̍쐬
    /// -ff[^A[Vf[^̓ǂݍ
    /// -[V̍Đ
    /// Ă܂
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        //MikuMikuDance for XNA
        MikuMikuDanceXNA mmd;
        //MMDff[^
        MMDModel model;
        //MMD[Vf[^
        MMDMotion motion;

        public Game1()
        {
            Content.RootDirectory = "Content";
            //foCXMMDX̕Kv𖞂Ă邩`FbN
            graphics = new GraphicsDeviceManager(this);
            MikuMikuDanceXNA.CheckDevice(graphics, true);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent֐
        /// e탍[h͂Ń[hsĂƗǂ
        /// </summary>
        protected override void LoadContent()
        {
            //MikuMikuDanceXNA쐬
            mmd = new MikuMikuDanceXNA(this);
            //vWFNgContentɒǉĂMiku.pmdf[h
            //[hMikuMikuDanceXNA.LoadModel֐ōs
            //(ff[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            model = mmd.LoadModel("Miku", this, Matrix.Identity);
            //ContentɒǉĂTrueMyHeart.vmd[V[h
            //[hMikuMikuDanceXNA.LoadMotion֐ōs
            motion = mmd.LoadMotion("TrueMyHeart");
            //f̃vC[Ăяo
            //[V0ԃgbNɃZbg
            model.Player.SetMotion(0, motion, true);
        }

        /// <summary>
        /// UnloadContent֐
        /// A[hKvȕ͂ŃA[hs
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Abvf[g֐
        /// t[`ȊÕR[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Update(GameTime gameTime)
        {
            //XBoxRg[[Back{^I
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //L[{[hEscL[I
            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
                this.Exit();
            //G^[L[orA{^Ƃ
            if (Keyboard.GetState().IsKeyDown(Keys.Enter) || GamePad.GetState(PlayerIndex.One).Buttons.A == ButtonState.Pressed)
            {
                //ݍĐłȂ
                if (!model.Player.IsPlay(0))
                {
                    //0ԃgbNɃZbgĂ郂[VZbg
                    model.Player.Reset(0);
                    //0ԃgbNɃZbgĂ郂[VĐ
                    model.Player.Start(0, false);
                }
            }

            //f̍ĐDrawableGameComponentpĂ邽
            //XNAɂ莩ŏs

            //XNAUpdates
            base.Update(gameTime);
        }

        /// <summary>
        /// Draw֐
        /// t[`R[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Draw(GameTime gameTime)
        {
            //ʂCornflowerBlueFŏ
            GraphicsDevice.Clear(Color.CornflowerBlue);

            //fDrawableGameComponentpĂ邽
            //XNAɂ莩ŕ`悳
            
            //XNADraws
            base.Draw(gameTime);
        }
    }
}

==> mmdx-tags_v1.50a-r928.tar.gz: mmdx-tags_v1.50a-r928/v1.50a/MikuMikuDanceXNADemo/Game1.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using MikuMikuDance.XNA.Model;
using MikuMikuDance.XNA;
using MikuMikuDance.XNA.Motion;
using MikuMikuDance.XNA.Model.ModelData;

namespace MikuMikuDanceXNADemo
{
    /// <summary>
    /// MikuMikuDance for XNÃf
    /// ̃fłMMDX̊{ł
    /// -MikuMikuDanceXNAIuWFNg̍쐬
    /// -ff[^A[Vf[^̓ǂݍ
    /// -[V̍Đ
    /// Ă܂
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        //MikuMikuDance for XNA
        MikuMikuDanceXNA mmd;
        //MMDff[^
        MMDModel model;
        //MMD[Vf[^
        MMDMotion motion;

        public Game1()
        {
            Content.RootDirectory = "Content";
            graphics = new GraphicsDeviceManager(this);
            //foCXMMDX̕Kv𖞂Ă邩`FbN
            MikuMikuDanceXNA.InitialSetup(this, graphics, true);
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent֐
        /// e탍[h͂Ń[hsĂƗǂ
        /// </summary>
        protected override void LoadContent()
        {
            //MikuMikuDanceXNA쐬
            mmd = new MikuMikuDanceXNA(this);
            //vWFNgContentɒǉĂMiku.pmdf[h
            //[hMikuMikuDanceXNA.LoadModel֐ōs
            //(ff[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            model = mmd.LoadModel("Miku", this, QuatTransform.Identity);
            //ContentɒǉĂTrueMyHeart.vmd[V[h
            //[hMikuMikuDanceXNA.LoadMotion֐ōs
            motion = mmd.LoadMotion("TrueMyHeart");
            //f̃vC[Ăяo
            //[V0ԃgbNɃZbg
            model.Player.SetMotion(0, motion, true);
        }

        /// <summary>
        /// UnloadContent֐
        /// A[hKvȕ͂ŃA[hs
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Abvf[g֐
        /// t[`ȊÕR[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Update(GameTime gameTime)
        {
            //XBoxRg[[Back{^I
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //L[{[hEscL[I
            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
                this.Exit();
            //G^[L[orA{^Ƃ
            if (Keyboard.GetState().IsKeyDown(Keys.Enter) || GamePad.GetState(PlayerIndex.One).Buttons.A == ButtonState.Pressed)
            {
                //ݍĐłȂ
                if (!model.Player.IsPlay(0))
                {
                    //0ԃgbNɃZbgĂ郂[VZbg
                    model.Player.Reset(0);
                    //0ԃgbNɃZbgĂ郂[VĐ
                    model.Player.Start(0, false);
                }
            }

            //f̍ĐDrawableGameComponentpĂ邽
            //XNAɂ莩ŏs

            //XNAUpdates
            base.Update(gameTime);
        }

        /// <summary>
        /// Draw֐
        /// t[`R[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Draw(GameTime gameTime)
        {
            //ʂCornflowerBlueFŏ
            GraphicsDevice.Clear(Color.CornflowerBlue);

            //fDrawableGameComponentpĂ邽
            //XNAɂ莩ŕ`悳
            
            //XNADraws
            base.Draw(gameTime);
        }
    }
}
